@@ -22,7 +22,40 @@ def create_from_template(module_: str = "models_user", current_folder: str = "."
     return False
 
 
+def create_from_content(
+    module_: str = "models_user", content: str = "", current_folder: str = "."
+):
+
+    file_path = Path(current_folder) / f"{module_}.py"
+    if not file_path.exists():
+        with open(file_path, "w") as dst:
+            dst.write(content)
+        return True
+    return False
+
+
 def init_user_files(current_folder: str = "."):
+    from .templates_content.models_ import models_content
+    from .templates_content.options_ import options_content
+    from .templates_content.main_ import main_content
+
+    create_example_files()
+    created = []
+    for module_, content in [
+        ("models_user", models_content),
+        ("options_user", options_content),
+        ("spml2_main", main_content),
+    ]:
+        if create_from_content(module_, content, current_folder):
+            created.append(module_)
+    if created:
+        for file in created:
+            print(f"Created: {file}")
+    else:
+        print("All initial files already exist.")
+
+
+def init_user_filesOld(current_folder: str = "."):
 
     create_example_files()
     created = [
