@@ -6,10 +6,6 @@ from spml2.parque_utils import df_to_stata
 
 
 def get_example_data() -> pd.DataFrame:
-    """
-    Loads the breast cancer dataset from sklearn and returns it as a pandas DataFrame.
-    The target column is named 'target'.
-    """
     data = load_breast_cancer(as_frame=True)
     df = data.frame
     return df
@@ -18,4 +14,7 @@ def get_example_data() -> pd.DataFrame:
 def create_example_files(folder: str = "input") -> None:
     folder = Path(folder)
     folder.mkdir(exist_ok=True)
-    df_to_stata(get_example_data(), folder / "example.dta")
+    file_name = folder / "example.dta"
+    if not file_name.exists():
+        print(f"Creating example data file: {file_name}")
+        df_to_stata(get_example_data(), file_name)
